package com.tfis.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.tfis.common.annotation.Log;
import com.tfis.common.core.controller.BaseController;
import com.tfis.common.core.domain.AjaxResult;
import com.tfis.common.enums.BusinessType;
import com.tfis.system.domain.FaultCaseViewCount;
import com.tfis.system.service.IFaultCaseViewCountService;
import com.tfis.common.utils.poi.ExcelUtil;
import com.tfis.common.core.page.TableDataInfo;

/**
 * 故障案例查看次数管理Controller
 * 
 * @author allen
 * @date 2023-11-23
 */
@RestController
@RequestMapping("/system/count")
public class FaultCaseViewCountController extends BaseController
{
    @Autowired
    private IFaultCaseViewCountService faultCaseViewCountService;

    /**
     * 查询故障案例查看次数管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:count:list')")
    @GetMapping("/list")
    public TableDataInfo list(FaultCaseViewCount faultCaseViewCount)
    {
        startPage();
        List<FaultCaseViewCount> list = faultCaseViewCountService.selectFaultCaseViewCountList(faultCaseViewCount);
        return getDataTable(list);
    }

    /**
     * 导出故障案例查看次数管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:count:export')")
    @Log(title = "故障案例查看次数管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FaultCaseViewCount faultCaseViewCount)
    {
        List<FaultCaseViewCount> list = faultCaseViewCountService.selectFaultCaseViewCountList(faultCaseViewCount);
        ExcelUtil<FaultCaseViewCount> util = new ExcelUtil<FaultCaseViewCount>(FaultCaseViewCount.class);
        util.exportExcel(response, list, "故障案例查看次数管理数据");
    }

    /**
     * 获取故障案例查看次数管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:count:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(faultCaseViewCountService.selectFaultCaseViewCountById(id));
    }

    /**
     * 新增故障案例查看次数管理
     */
    @PreAuthorize("@ss.hasPermi('system:count:add')")
    @Log(title = "故障案例查看次数管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FaultCaseViewCount faultCaseViewCount)
    {
        return toAjax(faultCaseViewCountService.insertFaultCaseViewCount(faultCaseViewCount));
    }

    /**
     * 修改故障案例查看次数管理
     */
    @PreAuthorize("@ss.hasPermi('system:count:edit')")
    @Log(title = "故障案例查看次数管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FaultCaseViewCount faultCaseViewCount)
    {
        return toAjax(faultCaseViewCountService.updateFaultCaseViewCount(faultCaseViewCount));
    }

    /**
     * 删除故障案例查看次数管理
     */
    @PreAuthorize("@ss.hasPermi('system:count:remove')")
    @Log(title = "故障案例查看次数管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(faultCaseViewCountService.deleteFaultCaseViewCountByIds(ids));
    }
}
